@@ -6,9 +6,9 @@ import jwt
 from google.protobuf.json_format import MessageToDict, ParseDict
 from twirp.context import Context  # type: ignore
 
-from .gen.video.coordinator.server_v1_rpc import server_rpc_pb2, server_rpc_twirp
-from .gen.video.coordinator.client_v1_rpc import client_rpc_pb2, client_rpc_twirp
 from .gen.video.coordinator.call_v1.call_pb2 import CallSettings
+from .gen.video.coordinator.client_v1_rpc import client_rpc_pb2, client_rpc_twirp
+from .gen.video.coordinator.server_v1_rpc import server_rpc_pb2, server_rpc_twirp
 
 try:
     from importlib import metadata  # type: ignore
@@ -29,7 +29,7 @@ def get_default_header() -> Dict[str, str]:
     }
 
 
-def message_to_dict(message):
+def message_to_dict(message: Any) -> Dict[str, Any]:
     """Converts protobuf message to a dictionary."""
     return MessageToDict(
         message,
@@ -39,11 +39,15 @@ def message_to_dict(message):
 
 class StreamVideo:
     def __init__(
-        self, api_key: str, api_secret: str, timeout: float = 6.0, **options: Any
+        self,
+        api_key: str,
+        api_secret: str,
+        timeout: float = 6.0,
+        **options: Dict[str, Any],
     ):
         self.base_url = "http://localhost:26991"
         if options.get("base_url"):
-            self.base_url = options["base_url"]
+            self.base_url = str(options["base_url"])
         elif os.getenv("STREAM_VIDEO_URL"):
             self.base_url = os.environ["STREAM_VIDEO_URL"]
 
@@ -76,7 +80,7 @@ class StreamVideo:
 
         self.options = options
 
-    def request(self, twirp_method, request_message):
+    def request(self, twirp_method: Any, request_message: Any) -> Dict[str, Any]:
         return message_to_dict(
             twirp_method(
                 ctx=self.ctx,
@@ -96,9 +100,9 @@ class StreamVideo:
             server_rpc_pb2.GetCallTypeRequest(name=name),
         )
 
-    def create_call_type(self, params: Dict[str, Any]) -> Dict:
+    def create_call_type(self, name: str, **settings: Dict[str, Any]) -> Dict:
         message = ParseDict(
-            params,
+            dict(name=name, settings=settings),
             server_rpc_pb2.CreateCallTypeRequest(),
             ignore_unknown_fields=True,
         )
@@ -112,7 +116,7 @@ class StreamVideo:
         )
         return self.request(self.server_side_twirp.UpdateCallType, message)
 
-    def delete_call_type(self, name: str) -> None:
+    def delete_call_type(self, name: str) -> Dict:
         message = server_rpc_pb2.DeleteCallTypeRequest(name=name)
         return self.request(self.server_side_twirp.DeleteCallType, message)
 
@@ -132,7 +136,7 @@ class StreamVideo:
         )
         return self.request(self.server_side_twirp.UpdateApp, message)
 
-    def _call_input(self, custom_data, settings_overrides):
+    def _call_input(self, custom_data: Dict, settings_overrides: Dict) -> Any:
         custom_data_encoded = json.dumps(custom_data or {})
         overrides = ParseDict(
             settings_overrides,
@@ -144,8 +148,12 @@ class StreamVideo:
         )
 
     def get_or_create_call(
-        self, call_type: str, call_id: str, custom_data: Dict, **settings_overrides
-    ):
+        self,
+        call_type: str,
+        call_id: str,
+        custom_data: Dict,
+        **settings_overrides: Dict[str, Any],
+    ) -> Dict:
         message = client_rpc_pb2.CreateCallRequest(
             type=call_type,
             id=call_id,
@@ -154,15 +162,19 @@ class StreamVideo:
         return self.request(self.client_side_twirp.GetOrCreateCall, message)
 
     def create_call(
-        self, call_type: str, call_id: str, custom_data: Dict, **settings_overrides
-    ):
+        self,
+        call_type: str,
+        call_id: str,
+        custom_data: Dict,
+        **settings_overrides: Dict[str, Any],
+    ) -> Dict:
         call_input = self._call_input(custom_data, settings_overrides)
         message = client_rpc_pb2.CreateCallRequest(
             type=call_type, id=call_id, input=call_input
         )
         return self.request(self.client_side_twirp.CreateCall, message)
 
-    def update_call(self):
+    def update_call(self) -> Dict:
         pass
 
     def query_session_timeline_events(self, session_id: str) -> Dict:
@@ -175,3 +187,41 @@ class StreamVideo:
         return self.request(
             self.server_side_twirp.QuerySessions, server_rpc_pb2.QuerySessionsRequest()
         )
+
+    def get_push_provider(self, provider_id: str) -> Dict:
+        return self.request(
+            self.server_side_twirp.GetPushProvider,
+            server_rpc_pb2.GetPushProviderRequest(id=provider_id),
+        )
+
+    def create_push_provider(
+        self, provider_id: str, **provider_settings: Dict[str, Any]
+    ) -> Dict:
+        return self.request(
+            self.server_side_twirp.CreatePushProvider,
+            server_rpc_pb2.CreatePushProviderRequest(
+                input=dict(id=provider_id, **provider_settings),
+            ),
+        )
+
+    def update_push_provider(
+        self, provider_id: str, **provider_settings: Dict[str, Any]
+    ) -> Dict:
+        return self.request(
+            self.server_side_twirp.UpdatePushProvider,
+            server_rpc_pb2.UpdatePushProviderRequest(
+                input=dict(id=provider_id, **provider_settings),
+            ),
+        )
+
+    def delete_push_provider(self, provider_id: str) -> Dict:
+        return self.request(
+            self.server_side_twirp.DeletePushProvider,
+            server_rpc_pb2.DeletePushProviderRequest(id=provider_id),
+        )
+
+    def query_push_providers(self) -> Dict:
+        return self.request(
+            self.server_side_twirp.QueryPushProviders,
+            server_rpc_pb2.QueryPushProvidersRequest(),
+        )
